import React from "react";
import {
	Box,
	Button,
	Card,
	CardContent,
	Container,
	Grid,
	Typography,
} from "@mui/material";
import { useNavigate } from "react-router-dom"; // Import useNavigate for navigation
import SearchIcon from "@mui/icons-material/Search";
import EvStationIcon from "@mui/icons-material/EvStation";
import BatteryChargingFullIcon from "@mui/icons-material/BatteryChargingFull";
import LocationOnIcon from "@mui/icons-material/LocationOn";
const features = [
	{
		icon: <EvStationIcon fontSize="large" />,
		title: "Seamless Charging Experience",
		description:
			"Find and book EV charging stations effortlessly with DigiEv's smart platform.",
	},
	{
		icon: <BatteryChargingFullIcon fontSize="large" />,
		title: "Real-Time Availability",
		description:
			"Check live station availability and optimize your route for an efficient charge.",
	},
	{
		icon: <LocationOnIcon fontSize="large" />,
		title: "Widespread Network",
		description:
			"Access a vast network of EV stations across multiple locations with ease.",
	},
	{
		icon: <SearchIcon fontSize="large" />, // New feature icon
		title: "Smart Search Functionality",
		description:
			"Find EV stations nearby with advanced filters for location, availability, and pricing.",
	},
];

const LandingPage = () => {
	const navigate = useNavigate();

	const handleLoginClick = () => {
		navigate("/login");
	};

	return (
		<Box
			sx={{
				background: `
      linear-gradient(135deg, #0D0D0D 20%, #1C1E22 80%), 
      radial-gradient(circle at  30%, rgb(241, 201, 119) 100%, rgba(255, 204, 102, 0) 50%)
    `,
				color: "white",
				minHeight: "100vh",
				fontFamily: "Inter",
				//display: "flex", // Ensures the children align correctly
				//flexDirection: "column",
			}}
		>
			{/* Navbar */}
			<Box
				component="nav"
				sx={{
					display: "flex",
					justifyContent: "space-between",
					alignItems: "center",
					py: 2,
					px: 3,
					maxWidth: "1200px",
					mx: "auto",
					fontFamily: "Inter",
				}}
			>
				<img
					src="/evLogo.png"
					alt="DigiEv Logo"
					style={{ height: "40px" }}
				/>
				<Box
					sx={{
						display: "flex",
						alignItems: "center",
						gap: 2,
					}}
				>
					<SearchIcon
						sx={{
							fontSize: "24px",
							cursor: "pointer",
							color: "#364056",
						}}
					/>
					<Button
						type="button"
						onClick={handleLoginClick}
						sx={{
							backgroundColor: "#52ACDF",
							color: "white",
							borderRadius: "8px",
							width: "117px",
							fontFamily: "Inter",
							textTransform: "none",
							"&:hover": { backgroundColor: "#439BC1" },
						}}
					>
						Login
					</Button>
				</Box>
			</Box>
			{/* Hero Section */}
			<Container
				sx={{
					py: 8,
					justifyContent: "space-between",
					fontFamily: "Inter",
				}}
			>
				<Grid
					container
					spacing={4}
					alignItems="center"
					justifyContent="center"
				>
					{/* Text Section */}
					<Grid
						item
						xs={12}
						md={6}
						sx={{
							height: { xs: "auto", md: "400px" },
							display: "flex",
							flexDirection: "column",
							justifyContent: "center",
						}}
					>
						<Typography
							sx={{
								fontFamily: "Inter",
								fontWeight: 600,
								fontSize: "40px",
								lineHeight: "120%",
								letterSpacing: "0px",
								marginBottom: "16px",
							}}
						>
							Empower Your Business With{" "}
							<Box component="span" sx={{ color: "#52ACDF" }}>
								Digital Evolution
							</Box>
							.
						</Typography>
						<Typography
							variant="body1"
							sx={{
								fontFamily: "Inter",
								color: "#CACACA",
								marginBottom: "24px",
								fontWeight: 400,
								fontSize: "20px",
								lineHeight: "120%",
							}}
						>
							DigiEv is your one-stop destination for transforming
							challenges into opportunities through innovative
							technology, seamless integration, and expert
							solutions.
						</Typography>
						<Button
							type="submit"
							sx={{
								backgroundColor: "#52ACDF",
								color: "white",
								borderRadius: "8px",
								width: "117px",
								textTransform: "none",
								fontFamily: "Inter",
								"&:hover": { backgroundColor: "#439BC1" },
							}}
						>
							Get in Touch
						</Button>
					</Grid>

					{/* Image Section */}
					<Grid
						item
						xs={12}
						md={6}
						sx={{
							display: "flex",
							justifyContent: "center",
							alignItems: "center",
						}}
					>
						<img
							src="/home.png"
							alt="Dashboard"
							style={{
								maxHeight: "100%",
								maxWidth: "100%",
								objectFit: "contain",
								borderRadius: "8px",
							}}
						/>
					</Grid>
				</Grid>
			</Container>

			<Container
				maxWidth="lg"
				sx={{
					// width: "1320px",
					// height: "239px",
					width: "100%",
					position: "relative",
					boxShadow: "0px 8px 20px rgba(166, 210, 235, 0.2)", // Bluish box shadow
					background:
						"linear-gradient(135deg, rgba(82, 172, 223, 0.2), rgba(0,0,0,0.3))",
					borderRadius: "16px",
					py: 4,
					px: 3,
					mt: 15,
				}}
			>
				<Grid container spacing={4} textAlign="center">
					<Grid item xs={12} md={3}>
						<Typography
							variant="h3"
							color="#52ACDF"
							fontWeight={600}
							fontSize={"80px"}
							lineHeight={"100px"}
							fontFamily={"Poppins"}
						>
							50+
						</Typography>
						<Typography
							variant="body2"
							color="#FFFFFF"
							fontFamily={"Inter"}
							fontWeight={400}
							fontSize={"16px"}
							lineHeight={"22px"}
						>
							Successful Digital Transformations
						</Typography>
					</Grid>
					<Grid item xs={12} md={3}>
						<Typography
							variant="h3"
							color="#52ACDF"
							fontWeight={600}
							fontSize={"80px"}
							lineHeight={"100px"}
							fontFamily={"Poppins"}
						>
							100%
						</Typography>
						<Typography
							variant="body2"
							color="#FFFFFF"
							fontFamily={"Inter"}
							fontWeight={400}
							fontSize={"16px"}
							lineHeight={"22px"}
						>
							Client Satisfaction
						</Typography>
					</Grid>
					<Grid item xs={12} md={3}>
						<Typography
							variant="h3"
							color="#52ACDF"
							fontWeight={600}
							fontSize={"80px"}
							lineHeight={"100px"}
							fontFamily={"Poppins"}
						>
							20+
						</Typography>
						<Typography
							variant="body2"
							color="#FFFFFF"
							fontFamily={"Inter"}
							fontWeight={400}
							fontSize={"16px"}
							lineHeight={"22px"}
						>
							Global Partnerships
						</Typography>
					</Grid>
					{/* New Statistic */}
					<Grid item xs={12} md={3}>
						<Typography
							variant="h3"
							color="#52ACDF"
							fontWeight={600}
							fontSize={"80px"}
							lineHeight={"100px"}
							fontFamily={"Poppins"}
						>
							10+
						</Typography>
						<Typography
							variant="body2"
							color="#FFFFFF"
							fontFamily={"Inter"}
							fontWeight={400}
							fontSize={"16px"}
							lineHeight={"22px"}
						>
							Years of Innovation
						</Typography>
					</Grid>
				</Grid>
			</Container>

			<Container
				maxWidth="lg"
				sx={{
					minHeight: "100vh",
					textAlign: "center",
					// width: "1320px",
					// height: "349.82px",
					width: "100%",
					boxShadow: "0px 8px 20px rgba(166, 210, 235, 0.2)", // Bluish box shadow
					background:
						"linear-gradient(135deg, rgba(82, 172, 223, 0.2), rgba(0,0,0,0.3))",
					borderRadius: "16px",
					py: 4,
					px: 3,
					mt: 10,
				}}
			>
				<Typography
					variant="h4"
					fontWeight={600}
					fontFamily={"Inter"}
					fontSize={"40px"}
					lineHeight={"100%"}
					color="#FFFFFF"
				>
					Welcome to <span style={{ color: "#52ACDF" }}>DigiEv</span>{" "}
					- Your EV Charging Partner
				</Typography>

				<Typography variant="h6" mt={1} fontWeight={600}>
					Simplifying Electric Vehicle Charging
				</Typography>
				<Typography
					variant="body1"
					mt={2}
					maxWidth="600px"
					mx="auto"
					fontFamily={"Inter"}
					fontSize={"20px"}
					fontWeight={400}
					lineHeight={"100%"}
					color="#D9D8D8"
				>
					DigiEv helps EV owners locate, book, and manage their
					charging needs efficiently. With our intuitive platform, you
					can ensure a smooth and hassle-free charging experience.
				</Typography>
				<Box mt={5}>
					<img
						src="/tablet-img.png"
						alt="DigiEv Dashboard"
						style={{
							width: "80%",
							maxWidth: "800px",
							borderRadius: "10px",
						}}
					/>
				</Box>
				<Grid
					container
					spacing={4}
					justifyContent="center"
					alignItems="center"
					mt={2}
				>
					{features.map((feature, index) => (
						<Grid item xs={12} sm={6} md={3} key={index}>
							<Card
								sx={{
									boxShadow:
										"0px 8px 20px rgba(166, 210, 235, 0.2)", // Bluish box shadow
									background:
										"linear-gradient(135deg, rgba(82, 172, 223, 0.2), rgba(0,0,0,0.3))",
									borderRadius: "18px",
									width: "247px", // Fixed width
									height: "200px", // Fixed height
									display: "flex", // Flexbox for centering content
									flexDirection: "column",
									alignItems: "center",
									justifyContent: "center",
									textAlign: "center",
								}}
							>
								<CardContent
									sx={{
										display: "flex",
										flexDirection: "column",
										alignItems: "center",
										justifyContent: "center",
										height: "100%", // Fills the parent card
										textAlign: "center",
									}}
								>
									<Box
										sx={{
											display: "flex",
											justifyContent: "center", // Centers the icon horizontally
											alignItems: "center", // Centers the icon vertically
											mt: 1,
											mb: 2,
											color: "#D9D8D8",
										}}
									>
										{feature.icon}
									</Box>
									<Typography
										variant="h6"
										sx={{
											color: "#52ACDF",
											fontFamily: "Inter",
											fontWeight: 600,
											fontSize: "18px", // Slightly reduced to fit uniformly
											lineHeight: "160%",
										}}
									>
										{feature.title}
									</Typography>
									<Typography
										variant="body2"
										sx={{
											color: "#D9D8D8",
											fontFamily: "Inter",
											fontWeight: 400,
											fontSize: "14px",
											lineHeight: "20px",
											mt: 1,
										}}
									>
										{feature.description}
									</Typography>
								</CardContent>
							</Card>
						</Grid>
					))}
				</Grid>
			</Container>
		</Box>
	);
};

export default LandingPage;
